@@ -6,7 +6,7 @@ use Mojo::UserAgent;
 use Carp 'croak';
 use strict;
 
-our $VERSION = '1.55';
+our $VERSION = '1.56';
 
 has providers => sub {
   return {
@@ -27,7 +27,7 @@ has providers => sub {
       token_url     => 'https://github.com/login/oauth/access_token',
     },
     google => {
-      authorize_url => "https://accounts.google.com/o/oauth2/v2/auth",
+      authorize_url => "https://accounts.google.com/o/oauth2/v2/auth?response_type=code",
       token_url     => "https://www.googleapis.com/oauth2/v4/token",
     },
     mocked => {authorize_url => '/mocked/oauth/authorize', token_url => '/mocked/oauth/token', secret => 'fake_secret'},
